@@ -11,8 +11,55 @@ import link
 import UserDict
 from functools import wraps
 
-class CanonicalRels(UserDict.DictMixin):
-    def __init__(self, rels, curie, base_uri):
+class CanonicalRels(UserDict.DictMixin, object):
+    """Smart querying of link relationship types and link relationships.
+
+    A ``CanonicalRels`` instance is a read-only dictionary-like object that
+    provides smart retrieval and de-duplication by link relationship type. It
+    is used to make access to links and embedded resources more convenient.
+    
+    In addition to well-know link relationship types (eg. ``"self"``), keys can
+    be custom link relationship types represented as URIs (eg.
+    ``"http://example.com/rels/comments"``), or as URI references (eg.
+    ``"/rels/comments"``), or as CURIEs (eg. ``"rel:comments"``).
+    ``CanonicalRels`` treats custom link relationship types as equivalent if
+    they expand to the same URI, called the canonical key here. Given a
+    suitable base URI and set of CURIE templates,
+    ``http://example.com/rels/comments``, ``/rels/comments``, and
+    ``rel:comments`` are all equivalent.
+
+    ``CanonicalRels`` de-duplicates items with equivalent keys.  De-duplication
+    is achieved by appending the new values to the existing values for the
+    canonical key. So, ``{"/rels/spam":eggs,"rel:spam":ham}`` becomes
+    ``{"http://example.com/rels/spam":[eggs,ham]}``.
+
+    Values can be retrieved using any key that is equivalent to the item's
+    canonical key.
+
+    """
+    def __init__(self, rels, curie, base_uri, item_filter=lambda _: True):
+        """Create a ``CanonicalRels`` instance.
+        
+        Arguments:
+
+        - ``rels``:        the relationships to be queried. ``rels`` should be
+                           a sequence of ``(key, value)`` tuples or an object
+                           with an ``iteritems`` method that returns such a
+                           sequence (such as a dictionary). For each tuple in
+                           the sequence, ``key`` is a string that identifies
+                           the link relationship type and ``value`` is the
+                           target of the relationship or a sequence of targets
+                           of the relationship.
+        - ``curie``:       a ``CurieCollection`` used to expand CURIE keys.
+        - ``base_uri``:    URL used as the basis when expanding keys that are
+                           relative URI references.
+        - ``item_filter``: optional filter on target relationships.
+                           ``item_filter`` should be a callable that accepts a
+                           target relationship and returns False if the target
+                           relationship should be excluded. ``item_filter``
+                           will be called once with each target relationship.
+
+        """
         if hasattr(rels, 'iteritems'):
             items = rels.iteritems()
         else:
@@ -30,38 +77,59 @@ class CanonicalRels(UserDict.DictMixin):
 
             original_key, current_value = self.rels[canonical_key]
 
-            if not hasattr(current_value, 'append'):
-                current_value = [current_value]
-                self.rels[canonical_key] = original_key, current_value
-
-            current_value.append(value)
+            new_value = [item for item in current_value if item_filter(item)]
+            new_value.extend(item for item in value if item_filter(item))
+            self.rels[canonical_key] = original_key, new_value
 
         self.rels = self.rels
 
     def canonical_key(self, key):
+        """Returns the canonical key for the given ``key``."""
         if key.startswith('/'):
             return urlparse.urljoin(self.base_uri, key)
         else:
             return self.curie.expand(key)
 
     def original_key(self, key):
+        """Returns the first key seen for the given ``key``."""
         return self.rels[self.canonical_key(key)][0]
 
     def __getitem__(self, key):
+        """Returns the link relationship that match the given ``key``.
+
+        ``self[key]`` will return any link relationship who's key is equivalent
+        to ``key``. Keys are equivalent if their canonical keys are equal.
+
+        If there is more than one link relationship that matches ``key``, a
+        list of matching link relationships is returned.
+
+        If there is one link relationship that matches ``key``, that link
+        relationship is returned.
+
+        If there are no link relationships that match ``key``, a ``KeyError``
+        is thrown.
+
+        """
         return self.rels[self.canonical_key(key)][1]
 
     def __contains__(self, key):
+        """Returns ``True`` if there are any link relationships for for
+        ``self[key].``
+        
+        """
         return self.canonical_key(key) in self.rels
 
     def keys(self):
+        """Returns a list of keys that map to every item.
+
+        Each key returned is an original key. That is, the first key
+        encountered for the canonical key.
+
+        """
         return [original_key for original_key, _ in self.rels.itervalues()]
 
-    def __equals__(self, other):
-        canonical_other = CanonicalRels(other, self.curie, self.base_uri).links
-        return self.rels == canonical_other
 
-
-class Relationships(UserDict.DictMixin):
+class Relationships(UserDict.DictMixin, object):
     """Merged view of relationships from a HAL document.
 
     Relationships, that is links and embedded resources, are presented as a
@@ -73,14 +141,13 @@ class Relationships(UserDict.DictMixin):
     relationships are presented in the order they appear in their respective
     collection.
 
-    Relationionships are deduplicated by their URL, as defined by their
-    ``self`` link in the case of embedded resources and by their ``href``
-    in the case of links. Only the first relationship with that URL will be
-    included.
+    Relationships are de-duplicated by their URL, as defined by their ``self``
+    link in the case of embedded resources and by their ``href`` in the case of
+    links. Only the first relationship with that URL will be included.
     
     """
 
-    def __init__(self, links, embedded, curie):
+    def __init__(self, links, embedded, curie, base_uri):
         """Initialize a ``Relationships`` object.
 
         Parameters:
@@ -96,26 +163,26 @@ class Relationships(UserDict.DictMixin):
                         URLs.
 
         """
-        self.rels = {}
+        rels = itertools.chain(embedded.iteritems(), links.iteritems())
 
-        item_urls = set()
-        for key, values in itertools.chain(embedded.iteritems(),
-                                           links.iteritems()):
-            rel_key = curie.expand(key)
+        existing_urls = set()
+        def item_filter(item):
+            url = item.url()
+            if url is not None and url in existing_urls:
+                return False
+            existing_urls.add(item.url())
+            return True
 
-            for value in values:
-                url = value.url()
-                if url is not None and url in item_urls:
-                    continue
-                item_urls.add(url)
-                
-                self.rels.setdefault(rel_key, []).append(value)
+        self.canonical_rels = CanonicalRels(rels, curie, base_uri, item_filter)
 
     def __getitem__(self, key):
-        return self.rels[key]
+        value = self.canonical_rels.__getitem__(key)
+        if not isinstance(value, list):
+            value = [value]
+        return value
 
     def keys(self):
-        return self.rels.keys()
+        return self.canonical_rels.keys()
          
 
 def mutator(fn):
@@ -216,7 +283,8 @@ class Document(object):
         self.curie = load_curie_collection()
         self.links = links_cache()
         self.embedded = embedded_cache()
-        self.rels = Relationships(self.links, self.embedded, self.curie)
+        self.rels = Relationships(self.links, self.embedded, self.curie,
+                                  self.base_uri)
 
     def url(self):
         """Returns the URL for the resource based on the ``self`` link.
@@ -254,7 +322,7 @@ class Document(object):
         return self.o
 
     def as_link(self):
-        """Returns a `Link` to the resource."""
+        """Returns a ``Link`` to the resource."""
         return self.links['self']
 
     @mutator
@@ -407,7 +475,7 @@ class Document(object):
 
     @classmethod
     def from_object(cls, o, base_uri=None, parent_curie=None):
-        """Returns a new ``Document`` based on a JSON object.
+        """Returns a new ``Document`` based on a JSON object or array.
 
         Arguments:
 
@@ -480,7 +548,7 @@ class Document(object):
         """Removes an embedded resource from this document.
 
         Calling code should use this method to remove embedded resources
-        instead of modyfying ``embedded`` directly.
+        instead of modifying ``embedded`` directly.
 
         The optional arguments, ``rel`` and ``href`` are used to select the
         embedded resources that will be removed. If neither of the optional
@@ -551,7 +619,7 @@ class Document(object):
         document.
 
         """
-        self.add_link('curie', href, name=name)
+        self.add_link('curie', href, name=name, templated=True)
 
     @mutator
     def drop_curie(self, name):
@@ -563,9 +631,13 @@ class Document(object):
         curies = self.o['_links']['curie']
         
         for i, curie in enumerate(curies):
-            if curie['name'] == name:
-                del curies[i]
-                break
+            try:
+                if curie['name'] == name:
+                    del curies[i]
+                    break
+            except:
+                import pdb;pdb.set_trace()
+            continue
 
     def __iter__(self):
         yield self
